@@ -21,7 +21,7 @@ def get_ft_level(input_row):
 
 
 def get_pg_level(input_row):
-    return get_ft_level(input_row)
+    return get_fft_level(input_row)
 
 def get_pg(input_row):
     centered_row = get_ft(input_row)
