@@ -185,7 +185,7 @@ def make_residual_bank(data_row, window_len=None):
     residuals = []
     
     if window_len is None:
-        window_len = min(conf['sf_models_smooth_window'], len(data_storage[i]) / 2.)
+        window_len = min(conf['sf_models_smooth_window'], len(data_storage[0]) / 2.)
     
     for i in xrange(len(data_storage)):
         smoothed = smooth(data_storage[i], window_len=window_len)
